//////////////////////////////////////////////////////////////////
// SEG_Init.sqf | Sahrani Electrical Grids v1.05
// Created by: Loyalguard
//////////////////////////////////////////////////////////////////

/* SCRIPT NOTES: This script is the core of the SEG Simulation. It determines which substation grids are created; creates the variables, game logics, and triggers required to simulate the grids; and adds the ability to manually control substation grid power if desired. There are three sections in this script: "Mission Maker Customization Options", "Substation Creation", and "JIP Player Update". All mission makers including SEG in their missions should review the below customization options to determine which substation grids are created and the option to manually turn power off and on at the substations. This mission is heavily commented for ease of review by the creator and mission makers alike. Since the code for each of the substations is nearly identical except for positions and variable names. As such, only the first section is commented. */

//++++++++++++++++++++++++++++++++++++
// Mission Maker Customization Options
//++++++++++++++++++++++++++++++++++++

/* SCRIPT NOTES: This script is the core of the SEG Simulation. It determines which substation grids are created; creates the variables, game logics, and triggers required to simulate the grids; and adds the ability to manually control substation grid power if desired. There are two sections in this script: "Mission Maker Customization Options" and "Substation Creation". All mission makers including SEG in their missions should review the below customization options to determine which substation grids are created and the option to manually turn power off and on at the substations. This mission is heavily commented for ease of review by the creator and mission makers alike. Since the code for each of the substations is nearly identical except for positions and variable names. As such, only the first section is commented. */// Select which substation grids you want to create. All seven substation grids will be created by default. If you do not want to create a substation change the 1 to 0 (0 = Skip, 1 = Include) for each entry below.

_optionIncludeParaiso = 1;
_optionIncludeOrtegoNorth = 1;
_optionIncludeOrtegoSouth = 1;
_optionIncludeDolores = 1;
_optionIncludeCorazolWest = 1;
_optionIncludeCorazolEast = 1;
_optionIncludeBagango = 1;

// Determines whether players can manually turn power off and on for all substations other than by causing damage using the action menu. 0 = No, 1 = Yes (default is 0).

_optionEnableSubPowerAction = 0;

// Determines whether a buzzer alarm will sound at a substation when a player turns power off and on. 0 = No, 1 = Yes (default is 0).

optionSoundBuzzer = 0;

// END OF CUSTOMIZATION: No further edits are required by mission makers for the remainder of this script.

//=============================
// Substation Creation
//=============================

// This section creates the variables, game logics, and triggers required for each substation grid if they option to include them was left as "1" above in "Mission Maker Customization Options". Individual substation code is grouped together in its own subsection.

//-----------------------------
// ParSub - Paraiso - 145699
//-----------------------------

// SPECIAL NOTE: Paraiso covers two grid zones so there are additional switchLight commands in trigParSubPower.

// If this substation is to be created then the code within the if block is executed.
if (_optionIncludeParaiso == 1) then
{
	//Initializes a pair of global variables that stores the current damage and power status (true=on, false=off) of the substation.
	LYGD_ParSubDamage = 0;
	LYGD_ParSubPower = true;

	// Creates a game logic that "locates" the nearby substation transformer object ("Land_trafostanica_velka").
	logicParSub = createVehicle ["Logic", [10854.244141,9610.269531,135.000000], [], 0, "NONE"];

	// Creates a trigger that monitors the damage level of the substation and broadcasts it if the substation is damaged more than 50%.
	trigParSubDamage = createTrigger["EmptyDetector",[10854.244141,9610.269531,135.000000]];
	trigParSubDamage setTriggerArea[0,0,0,false];
	trigParSubDamage setTriggerActivation["NONE","PRESENT",true];
	trigParSubDamage setTriggerStatements["getDammage (position logicParSub nearestObject ""Land_trafostanica_velka"") > .5", "LYGD_ParSubPower = false; publicVariable ""LYGD_ParSubPower""; LYGD_ParSubDamage = getDammage (position logicParSub nearestObject ""Land_trafostanica_velka""); publicVariable ""LYGD_ParSubDamage""", ""];

	// Creates a trigger that switches street lamps in the corresponding grid off and on if the substation is damaged or manually controlled.
	trigParSubPower = createTrigger["EmptyDetector",[10512.098633,9362.866211,138.518158]];
	trigParSubPower setTriggerArea[0,0,0,false];
	trigParSubPower setTriggerActivation["NONE","PRESENT",true];
	trigParSubPower setTriggerStatements["!LYGD_ParSubPower", "nul = [""ParSubPowerOnAct""] execVM ""SEG\SEG_Events.sqf""", "nul = [""ParSubPowerOnDea""] execVM ""SEG\SEG_Events.sqf"""];

	// Creates a trigger that executes a script that causes the substation (game logic) to emit a humming noise when energized.
	trigParSubHum = createTrigger["EmptyDetector",[10854.244141,9610.269531,135.000000]];
	trigParSubHum setTriggerArea[25,25,0,false];
	trigParSubHum setTriggerActivation["ANY","PRESENT",true];
	trigParSubHum setTriggerStatements["(player in thisList) &&  LYGD_ParSubPower", "LYGD_ParSubHum = true; nul = [""ParSubHum""] execVM ""SEG\SEG_SubHum.sqf""", "LYGD_ParSubHum = false"];

	// If players have been enabled to manually switch power off/on the code in the nested if block is executed.
	if (_optionEnableSubPowerAction == 1) then
	{
		// Creates a trigger that adds a "Power OFF" action to the substation if not damaged more than 50%.
		trigParSubActionPowerOff = createTrigger["EmptyDetector",[10854.244141,9610.269531,135.000000]];
		trigParSubActionPowerOff setTriggerArea[0,0,0,false];
		trigParSubActionPowerOff setTriggerActivation["NONE","PRESENT",true];
		trigParSubActionPowerOff setTriggerStatements["LYGD_ParSubPower && (LYGD_ParSubDamage < .5)", "LYGD_ParSubActionPowerOff = (position logicParSub nearestObject ""Land_trafostanica_velka"") AddAction [""> Power Substation OFF"",""SEG\SEG_Actions.sqf"",""ParSubActionPower""]", "(position logicParSub nearestObject ""Land_trafostanica_velka"") removeAction LYGD_ParSubActionPowerOff"];

		// Creates a trigger that adds a "Power ON" action to the substation if not damaged more than 50%.
		trigParSubActionPowerOn = createTrigger["EmptyDetector",[10854.244141,9610.269531,135.000000]];
		trigParSubActionPowerOn setTriggerArea[0,0,0,false];
		trigParSubActionPowerOn setTriggerActivation["NONE","PRESENT",true];
		trigParSubActionPowerOn setTriggerStatements["!LYGD_ParSubPower && (LYGD_ParSubDamage < .5)", "LYGD_ParSubActionPowerOn = (position logicParSub nearestObject ""Land_trafostanica_velka"") AddAction [""> Power Substation ON"",""SEG\SEG_Actions.sqf"",""ParSubActionPower""]", "(position logicParSub nearestObject ""Land_trafostanica_velka"") removeAction LYGD_ParSubActionPowerOn"];
	};
};

//-----------------------------
// OrtNSub - Ortego North - 188663
//-----------------------------

if (_optionIncludeOrtegoNorth == 1) then
{
	LYGD_OrtNSubDamage = 0;
	LYGD_OrtNSubPower = true;

	logicOrtNSub = createVehicle ["Logic", [12270.750977,7454.154297,28.500000], [], 0, "NONE"];

	trigOrtNSubDamage = createTrigger["EmptyDetector",[12270.750977,7454.154297,28.500000]];
	trigOrtNSubDamage setTriggerArea[0,0,0,false];
	trigOrtNSubDamage setTriggerActivation["NONE","PRESENT",true];
	trigOrtNSubDamage setTriggerStatements["getDammage (position logicOrtNSub nearestObject ""Land_trafostanica_velka"") > .5", "LYGD_OrtNSubPower = false; publicVariable ""LYGD_OrtNSubPower""; LYGD_OrtNSubDamage = getDammage (position logicOrtNSub nearestObject ""Land_trafostanica_velka""); publicVariable ""LYGD_OrtNSubDamage""", ""];

	trigOrtNSubPower = createTrigger["EmptyDetector",[12470.428711,7336.047363,18.968790]];
	trigOrtNSubPower setTriggerArea[0,0,0,false];
	trigOrtNSubPower setTriggerActivation["NONE","PRESENT",true];
	trigOrtNSubPower setTriggerStatements["!LYGD_OrtNSubPower", "nul = [""OrtNSubPowerOnAct""] execVM ""SEG\SEG_Events.sqf""", "nul = [""OrtNSubPowerOnDea""] execVM ""SEG\SEG_Events.sqf"""];

	trigOrtNSubHum = createTrigger["EmptyDetector",[12270.750977,7454.154297,28.500000]];
	trigOrtNSubHum setTriggerArea[25,25,0,false];
	trigOrtNSubHum setTriggerActivation["ANY","PRESENT",true];
	trigOrtNSubHum setTriggerStatements["(player in thisList) && LYGD_OrtNSubPower", "LYGD_OrtNSubHum = true; nul = [""OrtNSubHum""] execVM ""SEG\SEG_SubHum.sqf""", "LYGD_OrtNSubHum = false"];

	if (_optionEnableSubPowerAction == 1) then
	{
		trigOrtNSubActionPowerOff = createTrigger["EmptyDetector",[12270.750977,7454.154297,28.500000]];
		trigOrtNSubActionPowerOff setTriggerArea[0,0,0,false];
		trigOrtNSubActionPowerOff setTriggerActivation["NONE","PRESENT",true];
		trigOrtNSubActionPowerOff setTriggerStatements["LYGD_OrtNSubPower && (LYGD_OrtNSubDamage < .5)", "LYGD_OrtNSubActionPowerOff = (position logicOrtNSub nearestObject ""Land_trafostanica_velka"") AddAction [""> Power Substation OFF"",""SEG\SEG_Actions.sqf"",""OrtNSubActionPower""]", "(position logicOrtNSub nearestObject ""Land_trafostanica_velka"") removeAction LYGD_OrtNSubActionPowerOff"];

		trigOrtNSubActionPowerOn = createTrigger["EmptyDetector",[12270.750977,7454.154297,28.500000]];
		trigOrtNSubActionPowerOn setTriggerArea[0,0,0,false];
		trigOrtNSubActionPowerOn setTriggerActivation["NONE","PRESENT",true];
		trigOrtNSubActionPowerOn setTriggerStatements["!LYGD_OrtNSubPower && (LYGD_OrtNSubDamage < .5)", "LYGD_OrtNSubActionPowerOn = (position logicOrtNSub nearestObject ""Land_trafostanica_velka"") AddAction [""> Power Substation ON"",""SEG\SEG_Actions.sqf"",""OrtNSubActionPower""]", "(position logicOrtNSub nearestObject ""Land_trafostanica_velka"") removeAction LYGD_OrtNSubActionPowerOn"];
	};
};

//-----------------------------
// OrtSSub  Ortego South - 488559
//-----------------------------

if (_optionIncludeOrtegoSouth == 1) then
{
	LYGD_OrtSSubDamage = 0;
	LYGD_OrtSSubPower = true;

	logicOrtSSub = createVehicle ["Logic", [12177.541016,6958.848633,27.982933], [], 0, "NONE"];

	trigOrtSSubDamage = createTrigger["EmptyDetector",[12177.541016,6958.848633,27.982933]];
	trigOrtSSubDamage setTriggerArea[0,0,0,false];
	trigOrtSSubDamage setTriggerActivation["NONE","PRESENT",true];
	trigOrtSSubDamage setTriggerStatements["getDammage (position logicOrtSSub nearestObject ""Land_trafostanica_velka"") > .5", "LYGD_OrtSSubPower = false; publicVariable ""LYGD_OrtSSubPower""; LYGD_OrtSSubDamage = getDammage (position logicOrtSSub nearestObject ""Land_trafostanica_velka""); publicVariable ""LYGD_OrtSSubDamage""", ""];

	trigOrtSSubPower = createTrigger["EmptyDetector",[12230.956055,6930.266113,25.595676]];
	trigOrtSSubPower setTriggerArea[0,0,0,false];
	trigOrtSSubPower setTriggerActivation["NONE","PRESENT",true];
	trigOrtSSubPower setTriggerStatements["!LYGD_OrtSSubPower", "nul = [""OrtSSubPowerOnAct""] execVM ""SEG\SEG_Events.sqf""", "nul = [""OrtSSubPowerOnDea""] execVM ""SEG\SEG_Events.sqf"""];

	trigOrtSSubHum = createTrigger["EmptyDetector",[12177.541016,6958.848633,27.982933]];
	trigOrtSSubHum setTriggerArea[25,25,0,false];
	trigOrtSSubHum setTriggerActivation["ANY","PRESENT",true];
	trigOrtSSubHum setTriggerStatements["(player in thisList) && LYGD_OrtSSubPower", "LYGD_OrtSSubHum = true; nul = [""OrtSSubHum""] execVM ""SEG\SEG_SubHum.sqf""", "LYGD_OrtSSubHum = false"];

	if (_optionEnableSubPowerAction == 1) then
	{
		trigOrtSSubActionPowerOff = createTrigger["EmptyDetector",[12177.541016,6958.848633,27.982933]];
		trigOrtSSubActionPowerOff setTriggerArea[0,0,0,false];
		trigOrtSSubActionPowerOff setTriggerActivation["NONE","PRESENT",true];
		trigOrtSSubActionPowerOff setTriggerStatements["LYGD_OrtSSubPower && (LYGD_OrtSSubDamage < .5)", "LYGD_OrtSSubActionPowerOff = (position logicOrtSSub nearestObject ""Land_trafostanica_velka"") AddAction [""> Power Substation OFF"",""SEG\SEG_Actions.sqf"",""OrtSSubActionPower""]", "(position logicOrtSSub nearestObject ""Land_trafostanica_velka"") removeAction LYGD_OrtSSubActionPowerOff"];

		trigOrtSSubActionPowerOn = createTrigger["EmptyDetector",[12177.541016,6958.848633,27.982933]];
		trigOrtSSubActionPowerOn setTriggerArea[0,0,0,false];
		trigOrtSSubActionPowerOn setTriggerActivation["NONE","PRESENT",true];
		trigOrtSSubActionPowerOn setTriggerStatements["!LYGD_OrtSSubPower && (LYGD_OrtSSubDamage < .5)", "LYGD_OrtSSubActionPowerOn = (position logicOrtSSub nearestObject ""Land_trafostanica_velka"") AddAction [""> Power Substation ON"",""SEG\SEG_Actions.sqf"",""OrtSSubActionPower""]", "(position logicOrtSSub nearestObject ""Land_trafostanica_velka"") removeAction LYGD_OrtSSubActionPowerOn"];
	};
};

//-----------------------------
// DolSub - Dolores - 284731
//-----------------------------

if (_optionIncludeDolores == 1) then
{
	LYGD_DolSubDamage = 0;
	LYGD_DolSubPower = true;

	logicDolSub = createVehicle ["Logic", [11609.548828,6314.678223,14.835145], [], 0, "NONE"];
	trigDolSubDamage = createTrigger["EmptyDetector",[11609.548828,6314.678223,14.835145]];
	trigDolSubDamage setTriggerArea[0,0,0,false];
	trigDolSubDamage setTriggerActivation["NONE","PRESENT",true];
	trigDolSubDamage setTriggerStatements["getDammage (position logicDolSub nearestObject ""Land_trafostanica_velka"") > .5", "LYGD_DolSubPower = false; publicVariable ""LYGD_DolSubPower""; LYGD_DolSubDamage = getDammage (position logicDolSub nearestObject ""Land_trafostanica_velka""); publicVariable ""LYGD_DolSubDamage""", ""];

	trigDolSubPower = createTrigger["EmptyDetector",[11594.209961,6100.115723,17.464005]];
	trigDolSubPower setTriggerArea[0,0,0,false];
	trigDolSubPower setTriggerActivation["NONE","PRESENT",true];
	trigDolSubPower setTriggerStatements["!LYGD_DolSubPower", "nul = [""DolSubPowerOnAct""] execVM ""SEG\SEG_Events.sqf""", "nul = [""DolSubPowerOnDea""] execVM ""SEG\SEG_Events.sqf"""];

	trigDolSubHum = createTrigger["EmptyDetector",[11609.548828,6314.678223,14.835145]];
	trigDolSubHum setTriggerArea[25,25,0,false];
	trigDolSubHum setTriggerActivation["ANY","PRESENT",true];
	trigDolSubHum setTriggerStatements["(player in thisList) && LYGD_DolSubPower", "LYGD_DolSubHum = true; nul = [""DolSubHum""] execVM ""SEG\SEG_SubHum.sqf""", "LYGD_DolSubHum = false"];


	if (_optionEnableSubPowerAction == 1) then
	{
		trigDolSubActionPowerOff = createTrigger["EmptyDetector",[11609.548828,6314.678223,14.835145]];
		trigDolSubActionPowerOff setTriggerArea[0,0,0,false];
		trigDolSubActionPowerOff setTriggerActivation["NONE","PRESENT",true];
		trigDolSubActionPowerOff setTriggerStatements["LYGD_DolSubPower && (LYGD_DolSubDamage < .5)", "LYGD_DolSubActionPowerOff = (position logicDolSub nearestObject ""Land_trafostanica_velka"") AddAction [""> Power Substation OFF"",""SEG\SEG_Actions.sqf"",""DolSubActionPower""]", "(position logicDolSub nearestObject ""Land_trafostanica_velka"") removeAction LYGD_DolSubActionPowerOff"];

		trigDolSubActionPowerOn = createTrigger["EmptyDetector",[11609.548828,6314.678223,14.835145]];
		trigDolSubActionPowerOn setTriggerArea[0,0,0,false];
		trigDolSubActionPowerOn setTriggerActivation["NONE","PRESENT",true];
		trigDolSubActionPowerOn setTriggerStatements["!LYGD_DolSubPower && (LYGD_DolSubDamage < .5)", "LYGD_DolSubActionPowerOn = (position logicDolSub nearestObject ""Land_trafostanica_velka"") AddAction [""> Power Substation ON"",""SEG\SEG_Actions.sqf"",""DolSubActionPower""]", "(position logicDolSub nearestObject ""Land_trafostanica_velka"") removeAction LYGD_DolSubActionPowerOn"];
	};
};

//-----------------------------
// CorWSub  Corazol West - 288075 & 488815
//-----------------------------

// SPECIAL NOTE: Because there are two large transformers at this substation, instead of 50% damage, one of them must be 100% damaged for the power to switch off.

if (_optionIncludeCorazolWest == 1) then
{
	LYGD_CorWSubDamage = 0;
	LYGD_CorWSubPower = true;

	logicCorWSub = createVehicle ["Logic", [12958.742188,8646.105469,18.000000], [], 0, "NONE"];

	trigCorWSubDamage = createTrigger["EmptyDetector",[12958.742188,8646.105469,18.000000]];
	trigCorWSubDamage setTriggerArea[0,0,0,false];
	trigCorWSubDamage setTriggerActivation["NONE","PRESENT",true];
	trigCorWSubDamage setTriggerStatements["(getDammage (position logicCorWSub nearestObject 288075)) + (getDammage (position logicCorWSub nearestObject 488815)) > .49", "LYGD_CorWSubPower = false; publicVariable ""LYGD_CorWSubPower""; LYGD_CorWSubDamage = (getDammage (position logicCorWSub nearestObject 288075)) + (getDammage (position logicCorWSub nearestObject 488815)); publicVariable ""LYGD_CorWSubDamage""", ""];

	trigCorWSubPower = createTrigger["EmptyDetector",[12620.681641,8616.950195,27.266115]];
	trigCorWSubPower setTriggerArea[0,0,0,false];
	trigCorWSubPower setTriggerActivation["NONE","PRESENT",true];
	trigCorWSubPower setTriggerStatements["!LYGD_CorWSubPower", "nul = [""CorWSubPowerOnAct""] execVM ""SEG\SEG_Events.sqf""", "nul = [""CorWSubPowerOnDea""] execVM ""SEG\SEG_Events.sqf"""];

	trigCorWSubHum = createTrigger["EmptyDetector",[12958.742188,8646.105469,18.000000]];
	trigCorWSubHum setTriggerArea[40,40,0,false];
	trigCorWSubHum setTriggerActivation["ANY","PRESENT",true];
	trigCorWSubHum setTriggerStatements["(player in thisList) && LYGD_CorWSubPower", "LYGD_CorWSubHum = true; nul = [""CorWSubHum""] execVM ""SEG\SEG_SubHum.sqf""", "LYGD_CorWSubHum = false"];

	if (_optionEnableSubPowerAction == 1) then
	{
		trigCorWSubActionPowerOff = createTrigger["EmptyDetector",[12958.742188,8646.105469,18.000000]];
		trigCorWSubActionPowerOff setTriggerArea[0,0,0,false];
		trigCorWSubActionPowerOff setTriggerActivation["NONE","PRESENT",true];
		trigCorWSubActionPowerOff setTriggerStatements["LYGD_CorWSubPower && (LYGD_CorWSubDamage < .49)", "LYGD_CorWSubActionPowerOff = (position logicCorWSub nearestObject ""Land_trafostanica_velka"") AddAction [""> Power Substation OFF"",""SEG\SEG_Actions.sqf"",""CorWSubActionPower""]", "(position logicCorWSub nearestObject ""Land_trafostanica_velka"") removeAction LYGD_CorWSubActionPowerOff"];

		trigCorWSubActionPowerOn = createTrigger["EmptyDetector",[12958.742188,8646.105469,18.000000]];
		trigCorWSubActionPowerOn setTriggerArea[0,0,0,false];
		trigCorWSubActionPowerOn setTriggerActivation["NONE","PRESENT",true];
		trigCorWSubActionPowerOn setTriggerStatements["!LYGD_CorWSubPower && (LYGD_CorWSubDamage < .49)", "LYGD_CorWSubActionPowerOn = (position logicCorWSub nearestObject ""Land_trafostanica_velka"") AddAction [""> Power Substation ON"",""SEG\SEG_Actions.sqf"",""CorWSubActionPower""]", "(position logicCorWSub nearestObject ""Land_trafostanica_velka"") removeAction LYGD_CorWSubActionPowerOn"];
	};
};

//-----------------------------
// CorESub  Corazol East - 121255
//-----------------------------

// SPECIAL NOTE: There are two transformers at this substation but only one is a large transformer. The large one must be be 100% damaged for the power to switch off.

if (_optionIncludeCorazolEast == 1) then
{
	LYGD_CorESubDamage = 0;
	LYGD_CorESubPower = true;

	logicCorESub = createVehicle ["Logic", [13645.576172,9352.468750,20.969999], [], 0, "NONE"];

	trigCorESubDamage = createTrigger["EmptyDetector",[13645.576172,9352.468750,20.969999]];
	trigCorESubDamage setTriggerArea[0,0,0,false];
	trigCorESubDamage setTriggerActivation["NONE","PRESENT",true];
	trigCorESubDamage setTriggerStatements["getDammage (position logicCorESub nearestObject ""Land_trafostanica_velka"") > .99", "LYGD_CorESubPower = false; publicVariable ""LYGD_CorESubPower""; LYGD_CorESubDamage = getDammage (position logicCorESub nearestObject ""Land_trafostanica_velka""); publicVariable ""LYGD_CorESubDamage""", ""];

	trigCorESubPower = createTrigger["EmptyDetector",[13923.401367,9274.497070,40.409260]];
	trigCorESubPower setTriggerArea[0,0,0,false];
	trigCorESubPower setTriggerActivation["NONE","PRESENT",true];
	trigCorESubPower setTriggerStatements["!LYGD_CorESubPower", "nul = [""CorESubPowerOnAct""] execVM ""SEG\SEG_Events.sqf""", "nul = [""CorESubPowerOnDea""] execVM ""SEG\SEG_Events.sqf"""];

	trigCorESubHum = createTrigger["EmptyDetector",[13645.576172,9352.468750,20.969999]];
	trigCorESubHum setTriggerArea[25,25,0,false];
	trigCorESubHum setTriggerActivation["ANY","PRESENT",true];
	trigCorESubHum setTriggerStatements["(player in thisList) && LYGD_CorESubPower", "LYGD_CorESubHum = true; nul = [""CorESubHum""] execVM ""SEG\SEG_SubHum.sqf""", "LYGD_CorESubHum = false"];

	if (_optionEnableSubPowerAction == 1) then
	{
		trigCorESubActionPowerOff = createTrigger["EmptyDetector",[13645.576172,9352.468750,20.969999]];
		trigCorESubActionPowerOff setTriggerArea[0,0,0,false];
		trigCorESubActionPowerOff setTriggerActivation["NONE","PRESENT",true];
		trigCorESubActionPowerOff setTriggerStatements["LYGD_CorESubPower && (LYGD_CorESubDamage < .99)", "LYGD_CorESubActionPowerOff = (position logicCorESub nearestObject ""Land_trafostanica_velka"") AddAction [""> Power Substation OFF"",""SEG\SEG_Actions.sqf"",""CorESubActionPower""]", "(position logicCorESub nearestObject ""Land_trafostanica_velka"") removeAction LYGD_CorESubActionPowerOff"];

		trigCorESubActionPowerOn = createTrigger["EmptyDetector",[13645.576172,9352.468750,20.969999]];
		trigCorESubActionPowerOn setTriggerArea[0,0,0,false];
		trigCorESubActionPowerOn setTriggerActivation["NONE","PRESENT",true];
		trigCorESubActionPowerOn setTriggerStatements["!LYGD_CorESubPower && (LYGD_CorESubDamage < .99)", "LYGD_CorESubActionPowerOn = (position logicCorESub nearestObject ""Land_trafostanica_velka"") AddAction [""> Power Substation ON"",""SEG\SEG_Actions.sqf"",""CorESubActionPower""]", "(position logicCorESub nearestObject ""Land_trafostanica_velka"") removeAction LYGD_CorESubActionPowerOn"];
	};
};

//-----------------------------
// BagSub  Bagango - 299536
//-----------------------------

// SPECIAL NOTE: Bagango covers three grid zones so there are additional switchLight commands in trigBagSubPower.

if (_optionIncludeBagango == 1) then
{
	LYGD_BagSubDamage = 0;
	LYGD_BagSubPower = true;

	logicBagSub = createVehicle ["Logic", [14240.291016,12282.084961,49.960464], [], 0, "NONE"];

	trigBagSubDamage = createTrigger["EmptyDetector",[14240.291016,12282.084961,49.960464]];
	trigBagSubDamage setTriggerArea[0,0,0,false];
	trigBagSubDamage setTriggerActivation["NONE","PRESENT",true];
	trigBagSubDamage setTriggerStatements["getDammage (position logicBagSub nearestObject ""Land_trafostanica_velka"") > .5", "LYGD_BagSubPower = false; publicVariable ""LYGD_BagSubPower""; LYGD_BagSubDamage = getDammage (position logicBagSub nearestObject ""Land_trafostanica_velka""); publicVariable ""LYGD_BagSubDamage""", ""];

	trigBagSubPower = createTrigger["EmptyDetector",[14297.270508,12452.750000,54.319740]];
	trigBagSubPower setTriggerArea[0,0,0,false];
	trigBagSubPower setTriggerActivation["NONE","PRESENT",true];
	trigBagSubPower setTriggerStatements["!LYGD_BagSubPower", "nul = [""BagSubPowerOnAct""] execVM ""SEG\SEG_Events.sqf""", "nul = [""BagSubPowerOnDea""] execVM ""SEG\SEG_Events.sqf"""];
	
	trigBagSubHum = createTrigger["EmptyDetector",[14240.291016,12282.084961,49.960464]];
	trigBagSubHum setTriggerArea[25,25,0,false];
	trigBagSubHum setTriggerActivation["ANY","PRESENT",true];
	trigBagSubHum setTriggerStatements["(player in thisList) && LYGD_BagSubPower", "LYGD_BagSubHum = true; nul = [""BagSubHum""] execVM ""SEG\SEG_SubHum.sqf""", "LYGD_BagSubHum = false"];

	if (_optionEnableSubPowerAction == 1) then
	{
		trigBagSubActionPowerOff = createTrigger["EmptyDetector",[14240.291016,12282.084961,49.960464]];
		trigBagSubActionPowerOff setTriggerArea[0,0,0,false];
		trigBagSubActionPowerOff setTriggerActivation["NONE","PRESENT",true];
		trigBagSubActionPowerOff setTriggerStatements["LYGD_BagSubPower && (LYGD_BagSubDamage < .5)", "LYGD_BagSubActionPowerOff = (position logicBagSub nearestObject ""Land_trafostanica_velka"") AddAction [""> Power Substation OFF"",""SEG\SEG_Actions.sqf"",""BagSubActionPower""]", "(position logicBagSub nearestObject ""Land_trafostanica_velka"") removeAction LYGD_BagSubActionPowerOff"];

		trigBagSubActionPowerOn = createTrigger["EmptyDetector",[14240.291016,12282.084961,49.960464]];
		trigBagSubActionPowerOn setTriggerArea[0,0,0,false];
		trigBagSubActionPowerOn setTriggerActivation["NONE","PRESENT",true];
		trigBagSubActionPowerOn setTriggerStatements["!LYGD_BagSubPower && (LYGD_BagSubDamage < .5)", "LYGD_BagSubActionPowerOn = (position logicBagSub nearestObject ""Land_trafostanica_velka"") AddAction [""> Power Substation ON"",""SEG\SEG_Actions.sqf"",""BagSubActionPower""]", "(position logicBagSub nearestObject ""Land_trafostanica_velka"") removeAction LYGD_BagSubActionPowerOn"];
	};
};

LYGD_Grids = true; // Sets a global variable used by the init.sqf to determine when all pertinent grids have been created so a JIP update can take place.
  